@@ -82,9 +82,10 @@ function(object, ..., corr = FALSE, od = FALSE, pool = TRUE, unscaled = FALSE)
     
     if (inherits(invMat, "try-error"))
     {
+#        cat("Note: Variance-covariance matrix regularized\n")
         ## More stable than 'solve' (suggested by Nicholas Lewin-Koh - 2007-02-12)
         ch <- try(chol(scaledH), silent = TRUE)  
-        # "silent" argument added after report by Xuesong Yu - 2010-03-09
+        ## "silent" argument added after report by Xuesong Yu - 2010-03-09
         if (inherits(ch, "try-error")) 
         {
             ch <- try(chol(0.99 * object$fit$hessian + 0.01 * diag(dim(object$fit$hessian)[1])))
@@ -96,28 +97,6 @@ function(object, ..., corr = FALSE, od = FALSE, pool = TRUE, unscaled = FALSE)
     }
 }
 
-"rse" <- function(object, resvar = FALSE)
-{
-    if (!is.null(object$"objList"))
-    {
-        fitValue <- object$"minval"
-    } else {
-        fitValue <- object$"fit"$"value"
-    }
-
-    rse <- switch(object$"type",
-    "continuous" = fitValue / df.residual(object),
-    "binomial" = NA,
-    "Poisson" = NA)
-    
-    if (resvar) 
-    {
-        rse
-    } else {
-        sqrt(rse)
-    }
-}
-
 "vcDisc" <- function(object)
 {
     solve(object$fit$hessian)    
